.. _lino:

==============
Lino core docs
==============

Welcome to the **Lino** project homepage.

.. py2rst::

  from lino import SETUP_INFO
  print(SETUP_INFO['long_description'])


Content
========

.. toctree::
   :maxdepth: 1

   changes/index

   
